Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | function |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
src / main / python / okta_api_script / __init__.py | (no function) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / okta_api_script / cli.py | cli |  | 0% | 1 | 1 | 0 |  | 100% | 0 | 0 |  | 0%
src / main / python / okta_api_script / cli.py | (no function) |  | 100% | 11 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / okta_api_script / main.py | execute_api_cycle |  | 96% | 27 | 1 | 0 |  | 90% | 10 | 1 |  | 95%
src / main / python / okta_api_script / main.py | (no function) |  | 90% | 10 | 1 | 0 |  | 50% | 2 | 1 |  | 83%
src / main / python / services / __init__.py | (no function) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / enrollment.py | generate_server_enrollment_token |  | 100% | 6 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / enrollment.py | (no function) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / projects.py | get_projects_by_team |  | 100% | 9 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / projects.py | (no function) |  | 100% | 4 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / resource_groups.py | get_resource_groups_by_team |  | 100% | 9 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / resource_groups.py | get_projects_by_resource_group |  | 100% | 10 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / resource_groups.py | (no function) |  | 100% | 5 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / service_token.py | get_service_token |  | 100% | 12 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
src / main / python / services / service_token.py | (no function) |  | 100% | 4 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
Total |  |  | 97% | 117 | 3 | 0 |  | 83% | 12 | 2 |  | 96%

No items found using the specified filter.